import esbuild from "esbuild";
import process from "process";
import builtins from 'builtin-modules'
import child_process from 'child_process'
import fs from 'fs'

const banner =
`/*
THIS IS A GENERATED/BUNDLED FILE BY ESBUILD
if you want to view the source, please visit the github repository of this plugin
*/
`;

const prod = (process.argv[2] === 'production');

let runScriptPlugin = {
	name: 'run-script',
	setup(build) {
		build.onEnd(result => {
			if (result.errors.length > 0) {
				return
			}
			const scriptName = 'sync-plugin.sh'
			if (!fs.existsSync(scriptName)) {
				return
			}
			console.log(`run ${scriptName}`);
			child_process.exec(`bash ${scriptName}`, (err, stdout, stderr) => {
				if (err) {
					console.error(`run ${scriptName} error:`, err, stdout, stderr)
				}
			})
		})
	},
}

esbuild.build({
	banner: {
		js: banner,
	},
	entryPoints: ['main.ts', 'styles.css'],
	bundle: true,
	external: [
		'obsidian',
		'electron',
		...builtins],
	format: 'cjs',
	watch: !prod,
	target: 'es2016',
	logLevel: "info",
	sourcemap: prod ? false : 'inline',
	treeShaking: true,
	outdir: 'build',
	plugins: [runScriptPlugin],
}).catch(() => process.exit(1));
